@@ -8,14 +8,94 @@ use crate::{
 use lazy_static::lazy_static;
 use std::{collections::BTreeMap, collections::HashMap, iter::FromIterator};
 
+/// skip the first 3 circles for constructing our arcs, otherwise it will just be a mess
+pub const CIRCLES_TO_SKIP_FOR_ARC: usize = 3;
+
 #[derive(PartialEq, Debug, Clone, Copy)]
 /// edge cases of the circle art
-pub enum EdgeCase {
-    /// circle arc is touching the edge of the first cell
+pub enum Horizontal {
+    /// circle arc is touching the left edge of the first cell
     /// ie: if the left most cell is `/` then it is touching the dge
-    StartEdge,
+    LeftEdge,
     /// if the left most cell is `(` or `|` then it starts at half the cell
-    StartHalf,
+    Half,
+}
+
+pub struct CircleArt {
+    /// the ascii art of the circel
+    /// empty lines are ignored
+    /// empty vertical columns are ignored
+    ascii_art: &'static str,
+    start_edge: Horizontal,
+    /// distance in cell units, from the left edge of the ascii art to the center.x of the circle
+    offset_center_x: f32,
+    /// distance in cell units, from the top edge of the ascii art to the center.y of the circle
+    offset_center_y: f32,
+}
+
+impl CircleArt {
+    /// calculate the centel cell of this circle art
+    /// based on offset center
+    fn center_cell(&self) -> Cell {
+        let mut center_cell_x = self.offset_center_x - self.edge_increment_x();
+
+        // if no shared x (meaning even number of ascii art along x axis)
+        // we want to use the cell before it as the center cell
+        if !self.is_shared_x() {
+            center_cell_x -= 0.5;
+        }
+        let mut center_cell_y = self.offset_center_y;
+        if !self.is_shared_y() {
+            center_cell_y -= 0.5;
+        }
+        Cell::new(center_cell_x.floor() as i32, center_cell_y.floor() as i32)
+    }
+
+    /// returns the width in cells of the ascii art of this circle
+    fn width(&self) -> f32 {
+        let cb = CellBuffer::from(self.ascii_art);
+        let (lo, hi) = cb.bounds().expect("circle must have bounds");
+        match self.start_edge {
+            Horizontal::LeftEdge => (hi.x - lo.x) as f32 + 1.0,
+            Horizontal::Half => (hi.x - lo.x) as f32,
+        }
+    }
+
+    fn center(&self) -> Point {
+        let center_x = self.radius() + self.edge_increment_x();
+        let center_y = self.offset_center_y * 2.0;
+        Point::new(center_x, center_y)
+    }
+
+    fn edge_increment_x(&self) -> f32 {
+        match self.start_edge {
+            Horizontal::LeftEdge => 0.0,
+            Horizontal::Half => 0.5,
+        }
+    }
+    fn radius(&self) -> f32 {
+        self.width() / 2.0
+    }
+    fn diameter(&self) -> i32 {
+        (self.radius() * 2.0).floor() as i32
+    }
+
+    /// center cell at x will be shared if it is on the odd count
+    fn is_shared_x(&self) -> bool {
+        self.offset_center_x * 2.0 % 2.0 == 1.0
+    }
+
+    /// center cell at y will be shared if it is on the odd count
+    fn is_shared_y(&self) -> bool {
+        self.offset_center_y * 2.0 % 2.0 == 1.0
+    }
+}
+
+pub struct ArcSpans {
+    diameter: i32,
+    arc_spans: Vec<(Arc, Span)>,
+    is_shared_x: bool,
+    is_shared_y: bool,
 }
 
 // These are circle map, when a group is detected to have these set of characters
@@ -36,8 +116,14 @@ lazy_static! {
     ///     7├─┼─┼─┼─┤         │ │ │ │ │
     ///     8└─┴─┴─┴─┘        U└─┴─┴─┴─┘Y
     /// ```                      V W X
-    /// art, edge_case, top_offset to center point
-    static ref CIRCLE_ART_MAP: Vec<(&'static str, EdgeCase, f32)> =
+    /// (
+    /// art - the ascii art of the circle, the empty space is automatically removed
+    /// edge_case - where the edge from the left most cell of the circle
+    /// f32 - how many cell from the left most to the center.x of the circle
+    /// f32 - how many cell from the top most to the center.y of the circle,
+    /// Cell - center cell in arc2
+    /// )
+    static ref CIRCLE_ART_MAP: Vec<(&'static str, Horizontal,  f32, f32, Cell)> =
         vec![
             // CIRCLE_1
             //center 1,0,k, radius = 0.5
@@ -49,12 +135,12 @@ lazy_static! {
             //  cy_lies: mid
             //
             //  edge_case: start_half = 0.5, start_edge = 0.0
-            //  if radius +  edge_case has 0.5 then mid, 0.0 them edge
+            //  if radius +  edge_case has 0.5 then mid, 0.0 then edge
             //
             //
             (r#"
             ()
-            "#, EdgeCase::StartHalf, 0.5),
+            "#, Horizontal::Half, 1.0, 0.5, Cell::new(0,0)),
 
             // CIRCLE_2
             //center = 1,1,m radius = 1.0
@@ -64,7 +150,7 @@ lazy_static! {
             // cy_lies: mid
             (r#"
             (_)
-            "#, EdgeCase::StartHalf, 0.5),
+            "#, Horizontal::Half, 1.5, 0.5, Cell::new(1,0)),
 
             // CIRCLE_3
             //center = 1,1,o radius = 1.5,
@@ -75,7 +161,7 @@ lazy_static! {
             (r#"
              __
             (__)
-            "#,  EdgeCase::StartHalf, 1.5),
+            "#,  Horizontal::Half, 2.0, 1.5, Cell::new(1,1)),
 
             // CIRCLE_4
             //center: 2,1,m radius: 2.0
@@ -83,11 +169,14 @@ lazy_static! {
             //  vert_mid: half (1.5/3.0)
             // cx_lies: mid
             // cy_lies: mid
+            //
+            // shared x,  if starts at half and offset_center_x * 2.0 is odd
+            // shared y
             (r#"
              ,-.
             (   )
              `-'
-            "#,  EdgeCase::StartHalf, 1.5),
+            "#,  Horizontal::Half, 2.5, 1.5, Cell::new(2,1)),
 
             // CIRCLE_5
             //center: 2,1,o radius: 2.5
@@ -95,11 +184,14 @@ lazy_static! {
             // vert_mid: half (1.5/3.0)
             //  cx_lies: edge
             //  cy_lies: mid
+            //
+            //   no shared x, offset_center_x * 2.0 is even
+            //   shared y
             (r#"
              .--.
             (    )
              `--'
-            "#, EdgeCase::StartHalf, 1.5),
+            "#, Horizontal::Half, 3.0,  1.5, Cell::new(2,1)),
 
             // CIRCLE_6
             //center: 3,2,m radius: 3.0
@@ -107,12 +199,15 @@ lazy_static! {
             // vert_mid: 2.5/4
             // cx_lies: mid
             // cy_lies: mid
+            //
+            // shared x
+            // shared y
             (r#"
                _
              .' '.
             (     )
              `._.'
-            "#, EdgeCase::StartHalf, 2.5),
+            "#, Horizontal::Half, 3.5, 2.5, Cell::new(3,2)),
 
             // CIRCLE_7
             //center: 3,2,o radius: 3.5
@@ -120,12 +215,15 @@ lazy_static! {
             // vert_mid: 2.5/4
             //  cx_lies: edge
             //  cy_lies: mid
+            //
+            //  no shared x
+            //  shared y
             (r#"
                __
              ,'  '.
             (      )
              `.__.'
-            "#, EdgeCase::StartHalf, 2.5),
+            "#, Horizontal::Half, 4.0, 2.5, Cell::new(3,2)),
 
             // CIRCLE_8
             //center: 4,2,m radius:4.0
@@ -133,13 +231,16 @@ lazy_static! {
             // vert_mid: half (2.5/5.0)
             // cx_lies: mid
             // cy_lies: mid
+            //
+            // shared x
+            // shared y
             (r#"
                ___
              ,'   '.
             (       )
              `.   .'
                `-'
-            "#, EdgeCase::StartHalf, 2.5),
+            "#, Horizontal::Half, 4.5, 2.5, Cell::new(4,2)),
 
             // circle 9 and up can be divided into 4 quadrants these quadrants can be arcs and can be used as
             // rounded edge with larger radius for rouded rect
@@ -150,13 +251,16 @@ lazy_static! {
             // vert_mid:  3.0/5.0
             //  cx_lies: mid
             //  cy_lies: edge
+            //
+            //  shared x
+            //  no shared y
             (r#"
                ___
              ,'   `.
             /       \
             \       /
              `.___.'
-            "#,  EdgeCase::StartEdge, 3.0 ),
+            "#,  Horizontal::LeftEdge, 4.5, 3.0, Cell::new(4,2) ),
 
             // CIRCLE_10
             //center: 4,2,y radius: 5.0
@@ -165,13 +269,16 @@ lazy_static! {
             // vert_mid:  3.0/5.0
             //  cx_lies: edge
             //  cy_lies: edge
+            //
+            //  no shared x, if offset_center_x * 2.0 is even
+            //  no shared y, if the offset_center_y * 2.0 is even
             (r#"
                ____
              ,'    `.
             /        \
             \        /
              `.____.'
-            "#,  EdgeCase::StartEdge, 3.0),
+            "#,  Horizontal::LeftEdge, 5.0, 3.0, Cell::new(4,2)),
 
             // CIRCLE_11
             //center:5,3,o radius: 5.5
@@ -179,6 +286,9 @@ lazy_static! {
             // vert_mid:  3.5/6.0
             //  cx_lies: edge
             //  cy_lies: mid
+            //
+            //  no shared x
+            //  shared y
             (r#"
                 ____
               .'    `.
@@ -186,7 +296,7 @@ lazy_static! {
             (          )
              \        /
               `.____.'
-            "#, EdgeCase::StartHalf , 3.5),
+            "#, Horizontal::Half, 6.0, 3.5, Cell::new(5,3)),
 
             // CIRCLE_12
             //center:6,3,m radius: 6.0
@@ -194,6 +304,9 @@ lazy_static! {
             // vert_mid: 3.5/6.0
             // cx_lies: mid
             // cy_lies: mid
+            //
+            // shared x
+            // shared y
             (r#"
                 _____
               ,'     `.
@@ -201,13 +314,16 @@ lazy_static! {
             (           )
              \         /
               `._____.'
-            "#, EdgeCase::StartHalf, 3.5),
+            "#, Horizontal::Half, 6.5, 3.5, Cell::new(6,3)),
 
             // CIRCLE_13
             // center: 6,3,y radius: 6.5
             // vert_mid: 4.0/7.0
             //  cx_lies: edge
             //  cy_lies: edge
+            //
+            //  no shared x
+            //  no shared y
             (r#"
                 ______
               ,'      `.
@@ -216,13 +332,16 @@ lazy_static! {
             |            |
              \          /
               `.______.'
-            "#, EdgeCase::StartHalf, 4.0),
+            "#, Horizontal::Half, 7.0, 4.0, Cell::new(6,3)),
 
             // CIRCLE_14
             //center: 7,3,w radius: 7.0
             //vert_mid: 4.0/7.0
             //  cx_lies: mid
             //  cy_lies: edge
+            //
+            //  shared x
+            //  no shared y
             (r#"
                 _______
               ,'       `.
@@ -231,7 +350,7 @@ lazy_static! {
             |             |
              \           /
               `._______.'
-            "#, EdgeCase::StartHalf , 4.0),
+            "#, Horizontal::Half, 7.5, 4.0, Cell::new(7,3)),
 
 
             // CIRCLE_15
@@ -239,6 +358,9 @@ lazy_static! {
             //vert_mid: 4.5/8.0
             //  cx_lies: edge
             //  cy_lies: mid
+            //
+            //  no shared x
+            //  shared y
             (r#"
                 ________
               ,'        `.
@@ -248,13 +370,16 @@ lazy_static! {
             |              |
              \            /
               `.________.'
-            "#, EdgeCase::StartHalf, 4.5),
+            "#, Horizontal::Half, 8.0, 4.5, Cell::new(7,4)),
 
             // CIRCLE_16
             //center: 8,4,m radius: 8.0
             //vert_mid: 4.5/9.0
             // cx_lies: mid
             // cy_lies: mid
+            //
+            // shared x
+            // shared y
             (r#"
                 __-----__
               ,'         `.
@@ -265,13 +390,16 @@ lazy_static! {
              \             /
               `.         .'
                 `-------'
-            "#, EdgeCase::StartHalf, 4.5),
+            "#, Horizontal::Half, 8.5, 4.5, Cell::new(8,4)),
 
             // CIRCLE_17
             //center: 8,4,o radius: 8.5
             // vert_mid:  4.5/9.0
             //  cx_lies: edge
             //  cy_lies: mid
+            //
+            //  no shared x
+            //  shared y
             (r#"
                 .--------.
               ,'          `.
@@ -282,13 +410,16 @@ lazy_static! {
              \              /
               `.          .'
                 `--------'
-            "#, EdgeCase::StartHalf, 4.5),
+            "#, Horizontal::Half, 9.0, 4.5, Cell::new(8,4)),
 
             // CIRCLE_18
             //center:9,5,m radius: 9.0
             //vert_mid: 5.5/10.0
             // cx_lies: mid
             // cy_lies: mid
+            //
+            //  shared x
+            //  shared y
             (r#"
                 _.-'''''-._
               ,'           `.
@@ -300,13 +431,17 @@ lazy_static! {
              \               /
               `._         _.'
                  '-.....-'
-            "#, EdgeCase::StartHalf, 5.5),
+            "#, Horizontal::Half, 9.5,  5.5, Cell::new(9,5)),
 
             // CIRCLE_19
             // center: 9,5,o radius: 9.5
             // vert_mid:  5.5/10.0
             //  cx_lies: edge
             //  cy_lies: mid
+            //
+            // no shared x
+            // shared y
+            //
             (r#"
                 _.-''''''-._
               ,'            `.
@@ -318,7 +453,7 @@ lazy_static! {
              \                /
               `._          _.'
                  '-......-'
-            "#,  EdgeCase::StartHalf, 5.5),
+            "#,  Horizontal::Half, 10.0, 5.5, Cell::new(9,5)),
 
 
             // CIRCLE_20
@@ -326,6 +461,9 @@ lazy_static! {
             // vert_mid: 5.5/10.0
             // cx_lies: mid
             // cy_lies: mid
+            //
+            // shared x
+            // shared y
             (r#"
                 _.-'''''''-._
               ,'             `.
@@ -337,13 +475,16 @@ lazy_static! {
              \                 /
               `._           _.'
                  '-.......-'
-            "#, EdgeCase::StartHalf, 5.5),
+            "#, Horizontal::Half, 10.5, 5.5, Cell::new(10,5)),
 
             // CIRCLE_21
             // center: 10,5,o radius: 10.5
             // vert_mid: 5.5/11.0
             //  cx_lies: edge
             //  cy_lies: mid
+            //
+            // no shared x
+            // shared y
             (r#"
                 _.-''''''''-._
               ,'              `.
@@ -356,7 +497,7 @@ lazy_static! {
              \                  /
               `._            _.'
                  '-........-'
-            "#, EdgeCase::StartHalf, 5.5),
+            "#, Horizontal::Half, 11.0, 5.5, Cell::new(10,5)),
 
             // CIRCLE_22
             // center: 10,5,m radius: 11
@@ -364,6 +505,9 @@ lazy_static! {
             // vert_mid: 5.5/11.0
             // cx_lies: mid
             // cy_lies: mid
+            //
+            // shared x
+            // shared y
             (r#"
                 _.-'''''''''-._
               ,'               `.
@@ -376,39 +520,20 @@ lazy_static! {
              \                   /
               `._             _.'
                  '-.........-'
-            "#, EdgeCase::StartHalf, 5.5),
+            "#, Horizontal::Half, 11.5, 5.5, Cell::new(11, 5)),
 
         ];
 
 
-    static ref CIRCLE_MAP: Vec<(&'static str, Point, f32, EdgeCase, f32)> =Vec::from_iter(
-        CIRCLE_ART_MAP.iter().enumerate().map(|(ndx, (art, edge_case, offset_center_y))|{
-            let cb = CellBuffer::from(*art);
-            let (lo, hi) = cb.bounds().expect("circle must have bounds");
+    static ref CIRCLE_MAP: Vec<CircleArt> =Vec::from_iter(
+        CIRCLE_ART_MAP.iter().enumerate().map(|(ndx, (art, edge_case, offset_center_x, offset_center_y,arc2_center))|{
+            CircleArt{
+                ascii_art: *art,
+                start_edge: *edge_case,
+                offset_center_x: *offset_center_x,
+                offset_center_y: *offset_center_y,
+            }
 
-           let width = match *edge_case {
-               EdgeCase::StartEdge => {
-                    (hi.x - lo.x) as f32 + 1.0
-               }
-               EdgeCase::StartHalf => {
-                    (hi.x - lo.x) as f32
-               }
-           };
-
-           let calc_radius = width / 2.0;
-           let index = (width - 1.0) as usize;
-           assert_eq!(ndx, index);
-
-            let edge_inc_x = match edge_case{
-                EdgeCase::StartEdge => 0.0,
-                EdgeCase::StartHalf => 0.5,
-            };
-
-            let calc_center_x = calc_radius + edge_inc_x;
-            let calc_center_y = offset_center_y * 2.0;
-            let calc_center = Point::new(calc_center_x, calc_center_y);
-
-            (*art, calc_center, calc_radius, *edge_case, *offset_center_y)
         })
     );
 
@@ -416,30 +541,30 @@ lazy_static! {
     /// The fragments for each of the circle
     /// Calculate the span and get the group fragments
     static ref FRAGMENTS_CIRCLE: Vec<(Vec<Contacts>,Circle)> = Vec::from_iter(
-        CIRCLE_MAP.iter().map(|(art, center, radius, edge_case, offset_center_y)|{
-            (circle_art_to_group(art, &Settings::default()), Circle::new(*center, *radius, false))
+        CIRCLE_MAP.iter().map(|circle_art|{
+            (circle_art_to_group(circle_art.ascii_art, &Settings::default()), Circle::new(circle_art.center(), circle_art.radius(), false))
         })
     );
 
     /// map of circle spans and their radius
     pub static ref DIAMETER_CIRCLE: HashMap<i32,(Point,Span)> = HashMap::from_iter(
-        CIRCLE_MAP.iter().map(|(art, center, radius, edge_case, offset_center_y)|{
-            let cb = CellBuffer::from(*art);
+        CIRCLE_MAP.iter().map(|circle_art|{
+            let cb = CellBuffer::from(circle_art.ascii_art);
             let mut spans = cb.group_adjacents();
             assert_eq!(spans.len(), 1);
             let span = spans.remove(0).localize();
-            ((*radius * 2.0) as i32, (*center, span))
+            (circle_art.diameter(), (circle_art.center(), span))
         })
     );
 
     /// There is only 1 span per circle, and localized
     pub static ref CIRCLES_SPAN: BTreeMap<Circle, Span> = BTreeMap::from_iter(
-        CIRCLE_MAP.iter().map(|(art, center, radius, edge_case, offset_center_y)|{
-            let cb = CellBuffer::from(*art);
+        CIRCLE_MAP.iter().map(|circle_art|{
+            let cb = CellBuffer::from(circle_art.ascii_art);
             let mut spans = cb.group_adjacents();
             assert_eq!(spans.len(), 1);
             let span = spans.remove(0).localize();
-            (Circle::new(*center, *radius, false), span)
+            (Circle::new(circle_art.center(), circle_art.radius(), false), span)
         })
     );
 
@@ -454,31 +579,31 @@ lazy_static! {
     /// bottom_left  bottom   bottom_right
     ///
     /// (diameter, quarter arcs)
-    pub static ref QUARTER_ARC_SPAN: BTreeMap<i32, [(Arc,Span);4]> = BTreeMap::from_iter(
-        CIRCLE_MAP.iter().skip(3).map(|(art, center, radius, edge_case, offset_center_y)|{
-            let span = circle_art_to_span(art);
+    pub static ref QUARTER_ARC_SPAN: BTreeMap<i32, ArcSpans> = BTreeMap::from_iter(
+        CIRCLE_MAP.iter().skip(CIRCLES_TO_SKIP_FOR_ARC).map(|circle_art|{
+            let span = circle_art_to_span(circle_art.ascii_art);
             let bounds = span.cell_bounds().expect("must have bounds");
             let top_left = bounds.top_left();
             let bottom_right = bounds.bottom_right();
             let top_right = bounds.top_right();
             let bottom_left = bounds.bottom_left();
 
+            let center = circle_art.center();
+            let radius = circle_art.radius();
+
             let p1 = Point::new(center.x + radius, center.y);
             let p2 = Point::new(center.x, center.y - radius);
             let p3 = Point::new(center.x - radius, center.y);
             let p4 = Point::new(center.x, center.y + radius);
 
+            let arc2_center = circle_art.center_cell();
 
-            let center_cell = center.cell();
 
-            // TODO: use the edge_case from the circle_art map
-            let cx_adjusted = if !center.is_edge_x(){ center_cell.x }else{ center_cell.x - 1 };
-            let cy_adjusted = if !center.is_edge_y(){ center_cell.y }else{ center_cell.y - 1 };
+            let span1_center = Cell::new((center.x.floor() / Cell::width()) as i32, arc2_center.y);
+            let span2_center = arc2_center;
+            let span3_center = Cell::new(arc2_center.x, (center.y.floor() / Cell::height()) as i32);
+            let span4_center = Cell::new((center.x.floor() / Cell::width()) as i32, (center.y.floor() / Cell::height()) as i32);
 
-            let span1_center = Cell::new(center_cell.x, cy_adjusted);
-            let span2_center = Cell::new(cx_adjusted, cy_adjusted);
-            let span3_center = Cell::new(cx_adjusted, center_cell.y);
-            let span4_center = center_cell;
 
             let bounds1 = Cell::rearrange_bound(span1_center, top_right);
             let bounds2 = Cell::rearrange_bound(top_left, span2_center);
@@ -490,6 +615,7 @@ lazy_static! {
             let span3 = span.extract(bounds3.0, bounds3.1).localize();
             let span4 = span.extract(bounds4.0, bounds4.1).localize();
 
+
             let arc1_start  = bounds1.0.localize_point(p1);
             let arc1_end = bounds1.0.localize_point(p2);
 
@@ -502,43 +628,108 @@ lazy_static! {
             let arc4_start = bounds4.0.localize_point(p4);
             let arc4_end = bounds4.0.localize_point(p1);
 
-            let arc1 = Arc::new(arc1_start, arc1_end, *radius);
-            let arc2 = Arc::new(arc2_start, arc2_end, *radius);
-            let arc3 = Arc::new(arc3_start, arc3_end, *radius);
-            let arc4 = Arc::new(arc4_start, arc4_end, *radius);
+            let arc1 = Arc::new(arc1_start, arc1_end, radius);
+            let arc2 = Arc::new(arc2_start, arc2_end, radius);
+            let arc3 = Arc::new(arc3_start, arc3_end, radius);
+            let arc4 = Arc::new(arc4_start, arc4_end, radius);
 
-            let diameter = (*radius * 2.0) as i32;
-            (diameter, [(arc1, span1), (arc2, span2), (arc3, span3), (arc4, span4)])
+            let diameter = circle_art.diameter();
+            (diameter,
+            ArcSpans{
+                diameter,
+                arc_spans: vec![(arc1, span1), (arc2, span2), (arc3, span3), (arc4, span4)],
+                is_shared_x: circle_art.is_shared_x(),
+                is_shared_y: circle_art.is_shared_y(),
+            })
         })
     );
 
-    /*
-    pub static ref HALF_ARC_SPAN: BTreeMap<i32,[(Arc,Span);4]> = BTreeMap::from_iter(
-        QUARTER_ARC_SPAN.iter().map(|(diameter, [(arc1, span1), (arc2, span2), (arc3, span3), (arc4, span4)])|{
+    pub static ref HALF_ARC_SPAN: BTreeMap<i32, ArcSpans> = BTreeMap::from_iter(
+        QUARTER_ARC_SPAN.iter().map(|(diameter, arc_spans)|{
+            println!("at circle: {}", diameter);
             let radius = (diameter / 2) as f32;
+            let (arc1, span1) = &arc_spans.arc_spans[0];
+            let (arc2, span2) = &arc_spans.arc_spans[1];
+            let (arc3, span3) = &arc_spans.arc_spans[2];
+            let (arc4, span4) = &arc_spans.arc_spans[3];
+
+
+            let paste_loc12 = span2.cell_bounds().unwrap().top_right();
 
             let half12 = Arc::new(arc1.start, arc2.end, radius);
-            let span12 = span2.paste_at(span2.cell_bounds().unwrap().top_right(), span1);
+            let span12 = span2.paste_at(paste_loc12, span1);
+            println!("span12: \n{}\n", span12);
+            println!("half12: {}", half12);
 
+            let paste_loc23 = span2.cell_bounds().unwrap().bottom_left();
             let half23 = Arc::new(arc2.start, arc3.end, radius);
-            let span23 = span2.paste_at(span2.cell_bounds().unwrap().bottom_left(), span3);
+            let span23 = span2.paste_at(paste_loc23, span3);
+            println!("span23: \n{}\n", span23);
+            println!("half23: {}", half23);
 
+            let paste_loc34 = span3.cell_bounds().unwrap().top_right();
             let half34 = Arc::new(arc3.start, arc4.end, radius);
-            let span34 = span3.paste_at(span3.cell_bounds().unwrap().top_right(), span4);
+            let span34 = span3.paste_at(paste_loc34, span4);
+            println!("span34: \n{}\n", span34);
+            println!("half34: {}", half34);
 
+            let paste_loc41 = span1.cell_bounds().unwrap().bottom_left();
             let half41 = Arc::new(arc4.start, arc1.end, radius);
-            let span41 = span1.paste_at(span1.cell_bounds().unwrap().bottom_left(), span4);
+            let span41 = span1.paste_at(paste_loc41, span4);
+            println!("span41: \n{}\n", span41);
+            println!("half41: {}", half41);
+
+            (*diameter, ArcSpans{
+                diameter: *diameter,
+                arc_spans: vec![(half12, span12),(half23, span23),(half34, span34),(half41, span41)],
+                is_shared_x: arc_spans.is_shared_x,
+                is_shared_y: arc_spans.is_shared_y,
+            })
 
-            (*diameter, [(half12, span12), (half23, span23), (half34, span34), (half41, span41)])
         })
     );
-    */
 
-    pub static ref ARC_SPAN: BTreeMap<Arc,Span> = BTreeMap::from_iter(
-            QUARTER_ARC_SPAN.iter()
-                .flat_map(|(_diameter, arcs)|arcs.clone())
+
+
+    pub static ref FLATTENED_QUARTER_ARC_SPAN: BTreeMap<DiameterArc, (Arc,Span)> = BTreeMap::from_iter(
+            QUARTER_ARC_SPAN.iter().flat_map(|(diameter, arc_spans)|{
+                arc_spans.arc_spans.iter().enumerate().map(move|(arc_index, arc_span)|{
+                (DiameterArc{
+                    diameter: *diameter,
+                    arc: arc_index,
+                    },
+                    arc_span.clone()
+                )
+            })
+        })
     );
 
+    pub static ref FLATTENED_HALF_ARC_SPAN: BTreeMap<DiameterArc, (Arc,Span)> = BTreeMap::from_iter(
+            HALF_ARC_SPAN.iter().flat_map(|(diameter, arc_spans)|{
+                arc_spans.arc_spans.iter().enumerate().map(move|(arc_index, arc_span)|{
+                (DiameterArc{
+                    diameter: *diameter,
+                    arc: arc_index,
+                    },
+                    arc_span.clone()
+                )
+            })
+        })
+    );
+
+}
+
+#[derive(Default, Hash, PartialEq, PartialOrd, Eq)]
+pub struct DiameterArc {
+    diameter: i32,
+    arc: usize,
+}
+impl Ord for DiameterArc {
+    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
+        self.diameter
+            .cmp(&other.diameter)
+            .then(self.arc.cmp(&other.arc))
+    }
 }
 
 fn circle_art_to_group(art: &str, settings: &Settings) -> Vec<Contacts> {
@@ -576,27 +767,55 @@ pub fn endorse_circle_span(search: &Span) -> Option<(&Circle, Span)> {
     })
 }
 
-pub fn endorse_arc_span(search: &Span) -> Option<(&Arc, Span)> {
-    ARC_SPAN.iter().find_map(|(arc, span)| {
-        let search_localized = search.clone().localize();
-        let (matched, unmatched) = is_subset_of(span, &search_localized);
-        if matched {
-            let unmatched_cell_chars = search
-                .iter()
-                .enumerate()
-                .filter_map(|(i, cell_char)| {
-                    if unmatched.contains(&i) {
-                        Some(cell_char.clone())
-                    } else {
-                        None
-                    }
-                })
-                .collect::<Vec<_>>();
-            Some((arc, Span::from(unmatched_cell_chars)))
-        } else {
-            None
-        }
-    })
+pub fn endorse_quarter_arc_span(search: &Span) -> Option<(&Arc, Span)> {
+    FLATTENED_QUARTER_ARC_SPAN.iter().rev().find_map(
+        |(_diameter, (arc, span))| {
+            let search_localized = search.clone().localize();
+            let (matched, unmatched) = is_subset_of(span, &search_localized);
+            if matched {
+                let unmatched_cell_chars = search
+                    .iter()
+                    .enumerate()
+                    .filter_map(|(i, cell_char)| {
+                        if unmatched.contains(&i) {
+                            Some(cell_char.clone())
+                        } else {
+                            None
+                        }
+                    })
+                    .collect::<Vec<_>>();
+                Some((arc, Span::from(unmatched_cell_chars)))
+            } else {
+                None
+            }
+        },
+    )
+}
+
+pub fn endorse_half_arc_span(search: &Span) -> Option<(&Arc, Span)> {
+    FLATTENED_HALF_ARC_SPAN
+        .iter()
+        .rev()
+        .find_map(|(_diameter, (arc, span))| {
+            let search_localized = search.clone().localize();
+            let (matched, unmatched) = is_subset_of(span, &search_localized);
+            if matched {
+                let unmatched_cell_chars = search
+                    .iter()
+                    .enumerate()
+                    .filter_map(|(i, cell_char)| {
+                        if unmatched.contains(&i) {
+                            Some(cell_char.clone())
+                        } else {
+                            None
+                        }
+                    })
+                    .collect::<Vec<_>>();
+                Some((arc, Span::from(unmatched_cell_chars)))
+            } else {
+                None
+            }
+        })
 }
 
 /// returns true if all the contacts in subset is in big_set
